# AiiDA Yambo  

This is the official repository containing the AiiDA plugin and workflows for Yambo.

## Documentation

The documentation for this package can be found on Read the Docs at https://aiida-yambo.readthedocs.io/en/latest
[![Documentation Status](https://readthedocs.org/projects/aiida-yambo/badge/?version=latest)](https://aiida-yambo.readthedocs.io/en/latest/?badge=latest)

## Installation instructions:

Requirements: AiiDA (version >= 1.0.0b1), netCDF4

Installation via pip

```
pip install -e yambo-aiida
reentry scan
```

# License  
The terms of the yambo-aiida license can be found in the LICENSE.txt file.

[![Build Status](https://travis-ci.org/yambo-code/yambo-aiida.svg?branch=master)](https://travis-ci.org/yambo-code/yambo-aiida)

# Acknowledgements

This work is supported by the [MARVEL National Centre for Competency in Research](<http://nccr-marvel.ch>)
funded by the [Swiss National Science Foundation](<http://www.snf.ch/en>), as well as by the [MaX
European Centre of Excellence](<http://www.max-centre.eu/>) funded by the Horizon 2020 EINFRA-5 program,
Grant No. 676598.


![MARVEL](miscellaneous/logos/MARVEL.png) ![MaX](miscellaneous/logos/MaX.png)
